@@ -46,42 +46,49 @@
 #define USE_UCONTEXT 1
 
 #if defined(__OpenBSD__) || defined(__mips__)
-#undef USE_UCONTEXT
-#define USE_UCONTEXT 0
+# undef USE_UCONTEXT
+# define USE_UCONTEXT 0
 #endif
 
 #if defined(__APPLE__)
 # include <AvailabilityMacros.h>
-# if defined(MAC_OS_X_VERSION_10_5)
-#  undef USE_UCONTEXT
-#  define USE_UCONTEXT 0
+# if !defined(MAC_OS_X_VERSION_10_14)
+#  if !defined(__aarch64__)
+#    undef USE_UCONTEXT
+#    define USE_UCONTEXT 0
+#  endif
 # endif
 #endif
 
 #if USE_UCONTEXT
+# if defined(__APPLE__) && !defined(_XOPEN_SOURCE)
+#  define _XOPEN_SOURCE
+# endif
 # include <ucontext.h>
 #endif
 
 #if defined(__FreeBSD__) && __FreeBSD__ < 5
 extern int   getmcontext(mcontext_t*);
 extern void  setmcontext(const mcontext_t*);
-#define setcontext(u) setmcontext(&(u)->uc_mcontext)
-#define getcontext(u) getmcontext(&(u)->uc_mcontext)
+# define setcontext(u) setmcontext(&(u)->uc_mcontext)
+# define getcontext(u) getmcontext(&(u)->uc_mcontext)
 extern int   swapcontext(ucontext_t*, const ucontext_t*);
 extern void  makecontext(ucontext_t*, void(*)(void), int, ...);
 #endif
 
 #if defined(__APPLE__)
-# define mcontext libthread_mcontext
-# define mcontext_t libthread_mcontext_t
-# define ucontext libthread_ucontext
-# define ucontext_t libthread_ucontext_t
-# if defined(__i386__)
-#  include "386-ucontext.h"
-# elif defined(__x86_64__)
-#  include "amd64-ucontext.h"
-# else
-#  include "power-ucontext.h"
+# if !defined(__aarch64__)
+#  define mcontext libthread_mcontext
+#  define mcontext_t libthread_mcontext_t
+#  define ucontext libthread_ucontext
+#  define ucontext_t libthread_ucontext_t
+#  if defined(__i386__)
+#   include "386-ucontext.h"
+#  elif defined(__x86_64__)
+#   include "amd64-ucontext.h"
+#  else
+#   include "power-ucontext.h"
+#  endif
 # endif
 #endif
 
